/*
- many thanks to God [Yahwéh, YHWH, Geova]: He made life possible, and all you can do with it;
- many thanks to my wife and my children for their patience;
- many thanks to Rory Walsh for Cabbage and his great support (http://forum.cabbageaudio.com/);
- many thanks to Iain McCurdy, for his great support and all code shared (http://iainmccurdy.org/);
- many thanks to all users presents in the Cabbage forum: t_grey, Guillermo Senna in particular for your support and all code shared (http://forum.cabbageaudio.com/)
- many thanks to Riccardo Bianchini, Alessandro Cipriani, Giorgio Zucco, Jim Aikin for their wonderful books and "Vallste" for his (old) support (http://triceratupuz.altervista.org/);
- many thanks to Barry Vercoe, Richard Boulanger, Max Mathews and all Csound developers in the world (http://www.csounds.com/);

I'm not a writer of professional code in csound; in this example I would like to demonstrate how to use tables to control the amplitude and frequency of oscili:
a simple bass drum generator is born .....

Author: Tonetta Ivan (Ruben) - 2016.04 - Italy - Cabbage 1.02
*/
<Cabbage>
form size(440, 400), pluginID("plu1")

rslider  bounds(250,010,100,100), channel("master"), range(0.001,001,  .2, .5, 0.001), text("Master"),       textbox(1),      colour("silver"),      trackercolour("silver"),        fontcolour("silver")
rslider  bounds(247,190,100,100), channel("damp"),   range(  000,005, 001,001, 0.001), text("Dec Amp"),      textbox(1),      colour("red"),         trackercolour("red"),           fontcolour("red"),         textcolour("red")
rslider  bounds(337,190,100,100), channel("dfrq"),   range(  000,005, 001,001, 0.001), text("Dec Frq"),      textbox(1),      colour("green"),       trackercolour("green"),         fontcolour("green"),       textcolour("green")
rslider  bounds(337,010,100,100), channel("hfrq"),   range(  030,500, 050,001,   0.1), text("Kick Frq"),     textbox(1),      colour("blue"),        trackercolour("blue"),          fontcolour("blue"),        textcolour("blue")
; with the combobox below, the user sets the tables that will used for oscili
combobox bounds(270,330,055,020), channel("iamp"), items("Exp 2", "Lin 3"), colour("red"), fontcolour("black")
label    bounds(255,310,080,015), text("Amplitude"),   fontcolour("red")
combobox bounds(360,330,055,020), channel("ifrq"), items("Exp 2", "Lin 3"), colour("green"),   fontcolour("black")
label    bounds(350,310,080,015), text("Frequency"),   fontcolour("green")

gentable bounds(002,005,245,170), tablenumber(1), tablecolour("silver")
gentable bounds(002,185,245,170), tablenumber(2,3), tablecolour("silver", "gold"), identchannel("table") 

groupbox   bounds(004,365,330,027), linethickness(0), colour(160,160,160,020), plant("Background"){ 
	combobox   bounds(170,004,110,020), channel("combobox"), populate("*.snaps", "Presets")
	filebutton bounds(285,004,040,020), channel("save"), text("Save"), populate("*.snaps", "Presets")
	label      bounds(004,006,180,015), text("Tonetta Ivan - 2016.04"), align("left"), $LABEL
}
<CsoundSynthesizer>
<CsOptions>
-n -d -+rtmidi=NULL -M0 --midi-key-cps=4 ;--midi-velocity-amp=5 <-- amplitude of instr 1 is controlled by TABLE; no velocity, only Note ON.
</CsOptions>
<CsInstruments>
sr = 44100
ksmps = 16
nchnls = 2
0dbfs = 1
; Tables: Both Out of instr!
gisine  ftgen 1, 0, 4096, 10, 1 ; sine 
giamp1  ftgen 2, 0, 2048, 5, 1, 2047, .000001 ; exp table for amp
giamp2  ftgen 3, 0, 2048, 7, 1, 2047, 0       ; lin table for amp

instr 1
; Receive the widgets values
khfrq   chnget "hfrq"
idec1   chnget "damp"
idec2   chnget "dfrq"
iamp    chnget "iamp" ; you receive the combobox value: what is the table that will use for oscili?
ifreq   chnget "ifrq" ; this combobox select the frequency table used for oscili (remember: the tables are unipolar in the range 0, 1...)
kmaster chnget "master"
; when the user change the table with combobox selector, a trigger signal (1) is generated by "changed" opcode; 
ktrig1	changed iamp
; only when the trigger signal is 1, the value of iamp is updated to right table number: 2 is ftgen with exp curve and 3 is ftgen with lin curve
if (ktrig1 == 1) then
	if (iamp == 1) then
		iamp = 2
	else
		iamp = 3
	endif
endif
; when the user change the table with combobox selector, a trigger signal (1) is generated by "changed" opcode; 
ktrig2	changed ifreq
; only when the trigger signal is 1, the value of iffreq is updated to right table number: 2 is ftgen with exp curve and 3 is ftgen with lin curve
if (ktrig2 == 1) then
	if (ifreq == 1) then
		ifreq = 2
	else
		ifreq = 3
	endif
endif
; Amplitude curve: 
aline1  linseg 0, idec1, 2047 ; this line of code generate one segment from 0 to 2047 in the idec time: this is the index for reading the table
aenv   tablei aline1, iamp ; tablei reads the selected table with ifunc argument using the aline index
; Frequency curve:
kline2  linseg 0, idec2, 2047
kfrq   tablei kline2, ifreq
kfrq = khfrq * kfrq ; rescale the values at Kick freq GUI knob...
a1 oscili aenv*kmaster, kfrq, 1 ; oscili opcode is set by table amplitude and table frequency (still controlled by the master volume knob)
outs a1, a1

xtratim idec1 ; wait "idec" seconds after MIDI note off to...
turnoff ; turn off the instrument
endin

</CsInstruments>  
<CsScore>
;f0 3600
</CsScore>
</CsoundSynthesizer>